@@ -33,13 +33,14 @@ def read_kaggle_creds():
 
 def download_kaggle_dataset(dataset_url, data_dir, force=False, dry_run=False):
     dataset_id = get_kaggle_dataset_id(dataset_url)
-    id = dataset_id.split('/')[1] 
+    id = dataset_id.split('/')[1]
     target_dir = os.path.join(data_dir, id)
 
     if not force and os.path.exists(target_dir) and len(os.listdir(target_dir)) > 0:
-        print('Skipping, found downloaded files in "{}" (use force=True to force download)'.format(target_dir))
-        return 
-    
+        print('Skipping, found downloaded files in "{}" (use force=True to force download)'.format(
+            target_dir))
+        return
+
     if not read_kaggle_creds():
         print("Please provide your Kaggle credentials to download this dataset. Learn more: http://bit.ly/kaggle-creds")
         os.environ['KAGGLE_USERNAME'] = click.prompt("Your Kaggle username")
@@ -48,7 +49,7 @@ def download_kaggle_dataset(dataset_url, data_dir, force=False, dry_run=False):
     if not dry_run:
         from kaggle import api
         api.authenticate()
-        if dataset_id.split('/')[0] == 'c':
+        if dataset_id.split('/')[0] == 'competitions' or dataset_id.split('/')[0] == 'c':
             api.competition_download_files(
                 id,
                 target_dir,
@@ -67,6 +68,6 @@ def download_kaggle_dataset(dataset_url, data_dir, force=False, dry_run=False):
                 force=force,
                 quiet=False,
                 unzip=True)
-        
+
     else:
         print("This is a dry run, skipping..")
